@@ -1,4 +1,4 @@
-import pymysql, psycopg2, datetime, socket, configparser
+import pymysql, psycopg2, psycopg2.extras, datetime, socket, configparser
 
 host_ = socket.gethostbyname(socket.gethostname())
 port_ = 80 # Default XAMPP Apache server port.
@@ -9,7 +9,8 @@ curs_ = "DEFAULT"
 mode_ = "MySQL"
 
 # Make this differently, for the love of god!
-def bake(host=host_, port=port_, user=user_, pasw=pasw_, db=db_, cursor=curs_, mode=mode_, file=None):
+def bake(host=host_, port=port_, user=user_, pasw=pasw_, db=db_, cursor=curs_,
+         mode=mode_, file=None):
     global host_, port_, user_, pasw_, db_, curs_, mode_
     if file is None:
         if host != "": host_=host
@@ -57,7 +58,7 @@ def get_connection_object(conn):
     # PostgreSQL
     if (mode_ == "PostgreSQL"):
         if curs_ == "DICTIONARY":
-            return conn.cursor(cursor_factory=psycopg2.extras.RealDictCursor)
+            return conn.cursor(cursor_factory=psycopg2.extras.DictCursor)
         else:
             return conn.cursor()
     # MySQL (by Default)
@@ -87,10 +88,11 @@ def call(func, *args):
     return q[0][0] if (len(q)==1 and len(q[0])==1) else q
 
 # Quick SELECT-FROM-WHERE
-def sfw(select, from="", where=""):
+# /!\ Allow to pass lists too in the future.
+def sfw(select, fromm="", where=""):
     query_str = f"SELECT {select} "
-    if from:
-        query_str += f"FROM {from} "
+    if fromm:
+        query_str += f"FROM {fromm} "
     if where:
         query_str += f"WHERE {where};"
     return query(query_str)
